Encryptor

Struct Encryptor 

pub struct Encryptor<C: Config<F, T>, F: PrimeField256, const T: usize, const R: usize> { /* private fields */ }
Encrypts an arbitrary number of field elements in batches of R using the Poseidon permutation with state size T.

R must be T - 1 (the last element is reserved for capacity).

This symmetric cipher is implemented using the Poseidon PRP as a block cipher in duplex sponge mode, which is similar to CFB. The key lives in the capacity element.

Implementations

Source

impl<C: Config<F, T>, F: PrimeField256, const T: usize, const R: usize> Encryptor<C, F, T, R>

pub fn with_nonce(key: F, nonce: F) -> Self

Constructs an Encryptor with the specified key and nonce.

WARNING: NEVER reuse the same (key, nonce) pair to encrypt two or more different messages, as doing so would leak information about the plaintexts!

pub fn new(key: F) -> Self

Constructs an Encryptor with the specified key and a securely generated fresh nonce.

You can retrieve the nonce by calling Self::nonce.

pub fn nonce(&self) -> F

Returns the nonce used by the Encryptor.

This can be transmitted publicly along with the ciphertext and will be needed to construct the Decryptor.

pub fn encrypt(&mut self, block: [F; R]) -> [F; R]

Encrypts a block of R field elements.

pub fn finalize(self) -> F

Performs the final checksumming.